/*
    -- MAGMA (version 2.0) --
       Univ. of Tennessee, Knoxville
       Univ. of California, Berkeley
       Univ. of Colorado, Denver
       @date
*/

#ifndef MAGMA_CONFIG_H
#define MAGMA_CONFIG_H


// CUDA settings
#define MAGMA_HAVE_CUDA
#define MAGMA_CUDA_ARCH "75;80;86;87;88;89;90;100;103;110;120;121"
#define MAGMA_CUDA_ARCH_MIN 750

// HIP settings
/* #undef MAGMA_HAVE_HIP */



#endif  // MAGMA_CONFIG_H
